@@ -2,25 +2,24 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Ezgi Berberoğlu, 2018-2021                                    ###
+### Created by Ezgi Berberoğlu, 2017-2021                                    ###
 ###                                                                          ###
 ### Swiss Federal Institute of Technology (ETH), Zurich, Switzerland         ###
+### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
-### And Martin Genet, 2016-2019                                              ###
+### And Martin Genet, 2016-2022                                              ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
 ################################################################################
 
-from builtins import range
-
-import glob
-import numpy
-import vtk
 import math
+import numpy
 
 import myVTKPythonLibrary as myvtk
 
+import dolfin_warp as dwarp
+
 ################################################################################
 
 def compute_selective_image_gradient(
@@ -32,23 +31,23 @@ def compute_selective_image_gradient(
         masks_basename,
         masks_ext,
         mask_field_name,
-        suffix="",
+        suffix=None,
         verbose=0):
 
-    images_filenames = glob.glob(images_folder+"/"+images_basename+"_[0-9]*"+"."+images_ext)
-    masks_filenames = glob.glob(masks_folder+"/"+masks_basename+"_[0-9]*"+"."+masks_ext)
+    images_series = dwarp.ImagesSeries(
+        folder=images_folder,
+        basename=images_basename,
+        ext=images_ext)
+    masks_series = dwarp.ImagesSeries(
+        folder=masks_folder,
+        basename=masks_basename,
+        ext=masks_ext)
 
-    assert (len(images_filenames) == len(masks_filenames)),\
-        "Number of masks ("+str(len(masks_filenames))+") and images ("+str(len(images_filenames))+") are not the same. Aborting."
+    assert (images_series.n_frames == masks_series.n_frames),\
+        "Number of masks ("+str(masks_series.n_frames)+") and images ("+str(images_series.n_frames)+") are not the same. Aborting."
 
-    images_zfill = len(images_filenames[0].rsplit("_",1)[-1].split(".",1)[0])
-    masks_zfill = len(masks_filenames[0].rsplit("_",1)[-1].split(".",1)[0])
-
-    for k_frame in range(len(images_filenames)):
-        image_filename = images_folder+"/"+images_basename+"_"+str(k_frame).zfill(images_zfill)+"."+images_ext
-        image = myvtk.readImage(
-            filename=image_filename,
-            verbose=verbose-1)
+    for k_frame in range(images_series.n_frames):
+        image = images_series.get_image(k_frame=k_frame)
         n_points = image.GetNumberOfPoints()
         intensity_field = image.GetPointData().GetArray(images_field_name)
         intensity_tuple = numpy.empty(1)
@@ -59,10 +58,7 @@ def compute_selective_image_gradient(
         dimensions = image.GetDimensions()
         spacing = image.GetSpacing()
 
-        mask_filename = masks_folder+"/"+masks_basename+"_"+str(k_frame).zfill(masks_zfill)+"."+masks_ext
-        mask = myvtk.readImage(
-            filename=mask_filename,
-            verbose=verbose-1)
+        mask = masks_series.get_image(k_frame=k_frame)
         mask_field = mask.GetPointData().GetArray(mask_field_name)
         mask_tuple = numpy.empty(1)
 
@@ -87,16 +83,14 @@ def compute_selective_image_gradient(
                 k_point_y = int(math.floor((k_point - k_point_z*dimensions[0] * dimensions[1]) / dimensions[0]))
                 k_point_x = k_point - k_point_z*dimensions[0] * dimensions[1] - k_point_y*dimensions[0]
 
-                if (dimensionality>=1):
+                if (dimensionality >= 1):
                     maskValue_x_prev = mask_field.GetTuple1(k_point-1)
                     maskValue_x_next = mask_field.GetTuple1(k_point+1)
-
                     if   ((maskValue_x_prev == 1) and (maskValue_x_next != 1)) or (k_point_x == dimensions[0]-1):
                         #backward difference in x-direction (second condition is for boundary nodes- means that point is on the right border)
                         #if the mask covers the whole image, second condition is executed, otherwise not.
                         #Because gradient is computed only for the points having the mask value 1.
                         grad_tuple[0] = (intensity_field.GetTuple1(k_point) - intensity_field.GetTuple1(k_point-1))/spacing[0]
-
                     elif ((maskValue_x_prev != 1) and (maskValue_x_next == 1)) or (k_point_x == 0):
                         #forward difference in x-direction (second condition is for boundary nodes - means that point is on the left border)
                         grad_tuple[0] = (intensity_field.GetTuple1(k_point+1) - intensity_field.GetTuple1(k_point))/spacing[0]
@@ -104,7 +98,7 @@ def compute_selective_image_gradient(
                         #central difference
                         grad_tuple[0] = (intensity_field.GetTuple1(k_point+1) - intensity_field.GetTuple1(k_point-1))/(2*spacing[0])
 
-                if (dimensionality>=2):
+                if (dimensionality >= 2):
                     maskValue_y_prev = mask_field.GetTuple1(k_point-dimensions[1])
                     maskValue_y_next = mask_field.GetTuple1(k_point+dimensions[1])
                     if   ((maskValue_y_prev == 1) and (maskValue_y_next != 1)) or (k_point_y == dimensions[1]-1):
@@ -117,13 +111,13 @@ def compute_selective_image_gradient(
                         #central difference
                         grad_tuple[1] = (intensity_field.GetTuple1(k_point+dimensions[1]) - intensity_field.GetTuple1(k_point-dimensions[1]))/(2*spacing[1])
 
-                if (dimensionality>=3):
+                if (dimensionality >= 3):
                     if (k_point-dimensions[0]*dimensions[1]) < 0:
                         maskValue_z_prev = 0
                     else:
                         maskValue_z_prev = mask_field.GetTuple1(k_point-dimensions[0]*dimensions[1])
 
-                    if (k_point+dimensions[0]*dimensions[1]) >=  dimensions[2]:
+                    if (k_point+dimensions[0]*dimensions[1]) >= dimensions[2]:
                         maskValue_z_next = 0
                     else:
                         maskValue_z_next = mask_field.GetTuple1(k_point+dimensions[0]*dimensions[1])
@@ -142,5 +136,5 @@ def compute_selective_image_gradient(
 
         myvtk.writeImage(
             image=image,
-            filename=images_folder+"/"+images_basename+("_"+suffix)*(suffix!="")+"_"+str(k_frame).zfill(images_zfill)+"."+images_ext,
+            filename=images_series.get_image_filename(k_frame=k_frame, suffix=suffix),
             verbose=verbose-1)
