@@ -2,7 +2,7 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2016-2021                                       ###
+### Created by Martin Genet, 2016-2022                                       ###
 ###                                                                          ###
 ### École Polytechnique, Palaiseau, France                                   ###
 ###                                                                          ###
@@ -11,11 +11,8 @@
 import dolfin
 import numpy
 
-import myPythonLibrary    as mypy
 import myVTKPythonLibrary as myvtk
 
-import dolfin_warp as dwarp
-
 ################################################################################
 
 def getScalingFactor(scalar_type_as_string):
